@@ -66,10 +66,10 @@ impl MessageBox {
             WaitForSingleObject(event, 0);
             CloseHandle(event);
 
-            let result = MessageBoxA(
+            let result = MessageBoxW(
                 frame.get_window(),
-                self.message.as_ptr(),
-                self.title.as_ptr(),
+                self.message.encode_utf16().collect::<Vec<u16>>().as_mut_ptr(),
+                self.title.encode_utf16().collect::<Vec<u16>>().as_mut_ptr(),
                 self.style | self.button_style,
             );
             result
