@@ -105,6 +105,7 @@ pub const WINDOWSTYLE_NORMAL: windows_sys::Win32::UI::WindowsAndMessaging::WINDO
 #[cfg(windows)]
 /// A window with only a close button
 pub const WINDOWSTYLE_ONLYEXIT: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE = windows_sys::Win32::UI::WindowsAndMessaging::WS_SYSMENU;
+#[deprecated(since="0.9.2", note="This constant has been discontinued.")]
 #[cfg(windows)]
 /// Window with no caption
 pub const WINDOWSTYLE_NOCAPTION: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_STYLE = windows_sys::Win32::UI::WindowsAndMessaging::WS_CAPTION;
@@ -113,7 +114,13 @@ pub const WINDOWSTYLE_NOCAPTION: windows_sys::Win32::UI::WindowsAndMessaging::WI
 #[cfg(unix)]
 /// Standard window
 pub const WINDOWSTYLE_NORMAL: gtk::WindowType = gtk::WindowType::Toplevel;
+#[cfg(unix)]
+/// A window with only a close button
+pub const WINDOWSTYLE_NOCAPTION: gtk::WindowType = gtk::WindowType::Popup;
 
 #[cfg(windows)]
 #[cfg(feature="nxui-awc")]
 pub const ADVANCED_WINDOWSTYLE_UTILITY: windows_sys::Win32::UI::WindowsAndMessaging::WINDOW_EX_STYLE = windows_sys::Win32::UI::WindowsAndMessaging::WS_EX_TOOLWINDOW;
+#[cfg(unix)]
+#[cfg(feature="nxui-awc")]
+pub const ADVANCED_WINDOWSTYLE_UTILITY: gtk::gdk::WindowTypeHint = gtk::gdk::WindowTypeHint::Utility;
