@@ -1,5 +1,5 @@
-use crate::io::get_app_dirs;
-use crate::io::storage::Storage;
+// use crate::io::get_app_dirs;
+// use crate::io::storage::Storage;
 use crate::window::{Application, Frame};
 
 #[cfg(windows)]
@@ -10,9 +10,9 @@ pub fn create_new_app(application: Box<dyn Application>) {
     let app_name = application.app_name();
     // Get attributes
     let attributes = application.attributes();
-    let storage = Storage::new(get_app_dirs(app_name));
+    // let storage = Storage::new(get_app_dirs(app_name));
     // startup process
-    application.startup(storage);
+    // application.startup(storage);
 
     // Create a window
     use windows_sys::{Win32::Foundation::*, Win32::Graphics::Gdi::ValidateRect, Win32::System::LibraryLoader::GetModuleHandleA, Win32::UI::WindowsAndMessaging::*};
@@ -76,16 +76,16 @@ pub fn create_new_app(application: Box<dyn Application>) {
 /// Run nxui::window::Application
 pub fn create_new_app(application: Box<dyn Application>) {
     // Get window title
-    let app_name = application.app_name();
+    let _app_name = application.app_name();
     // Get attributes
     let attributes = application.attributes();
     // Get Advanced Options
     let advanced_options = application.advanced_options();
-    let storage = Storage::new(get_app_dirs(app_name));
+    // let storage = Storage::new(get_app_dirs(app_name));
     // startup process
-    if attributes.is_childwindow == false {
-        application.startup(storage);
-    }
+    // if attributes.is_childwindow == false {
+    //     application.startup(storage);
+    // }
 
     // Create a window
     use windows_sys::{Win32::Foundation::*, Win32::Graphics::Gdi::ValidateRect, Win32::System::LibraryLoader::GetModuleHandleA, Win32::UI::WindowsAndMessaging::*};
@@ -151,9 +151,9 @@ pub fn create_new_app(application: Box<dyn Application>) {
     let app_name = application.app_name();
     // Get attributes
     let attributes = application.attributes();
-    let storage = Storage::new(get_app_dirs(app_name));
+    // let storage = Storage::new(get_app_dirs(app_name));
     // startup process
-    application.startup(storage);
+    // application.startup(storage);
 
     // Create a window
     use gtk::prelude::*;
@@ -190,9 +190,9 @@ pub fn create_new_app(application: Box<dyn Application>) {
     let attributes = application.attributes();
     // Get advanced_options
     let advanced_options = application.advanced_options();
-    let storage = Storage::new(get_app_dirs(app_name));
+    // let storage = Storage::new(get_app_dirs(app_name));
     // startup process
-    application.startup(storage);
+    // application.startup(storage);
 
     // Create a window
     use gtk::prelude::*;
